public static class AsyncFeign.AsyncBuilder<C> extends BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>
capabilities, closeAfterDecode, contract, decoder, decodeVoid, dismiss404, encoder, errorDecoder, invocationHandlerFactory, logger, logLevel, methodInterceptors, options, propagationPolicy, queryMapEncoder, requestInterceptors, responseInterceptors, retryer| Constructor and Description |
|---|
AsyncBuilder() |
addCapability, build, codec, exceptionPropagationPolicy, responseInterceptor, responseInterceptorChain, responseInterceptors, retryer@Deprecated public AsyncFeign.AsyncBuilder<C> defaultContextSupplier(Supplier<C> supplier)
public AsyncFeign.AsyncBuilder<C> client(AsyncClient<C> client)
public AsyncFeign.AsyncBuilder<C> executorService(ExecutorService executorService)
ExecutorService used by the default AsyncClient to run the
(blocking) underlying client calls. When provided, the caller owns the executor's lifecycle
and is responsible for shutting it down. This is the recommended way to avoid the ClassLoader leak described in gh-3178: supply a managed, shut-downable executor instead of
relying on the built-in default. Ignored when a custom client(AsyncClient) is
supplied.public AsyncFeign.AsyncBuilder<C> methodInfoResolver(MethodInfoResolver methodInfoResolver)
public AsyncFeign.AsyncBuilder<C> mapAndDecode(ResponseMapper mapper, Decoder decoder)
BaseBuildermapAndDecode in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>public AsyncFeign.AsyncBuilder<C> decoder(Decoder decoder)
decoder in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>@Deprecated public AsyncFeign.AsyncBuilder<C> decode404()
BaseBuilderdecoder should process responses with
404 status, specifically returning null or empty instead of throwing FeignException.
All first-party (ex gson) decoders return well-known empty values defined by Util.emptyValueOf(java.lang.reflect.Type). To customize further, wrap an existing decoder or
make your own.
This flag only works with 404, as opposed to all or arbitrary status codes. This was an
explicit decision: 404 -> empty is safe, common and doesn't complicate redirection, retry or
fallback policy. If your server returns a different status for not-found, correct via a custom
client.
decode404 in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>public AsyncFeign.AsyncBuilder<C> dismiss404()
BaseBuilderdecoder should process responses with
404 status, specifically returning null or empty instead of throwing FeignException.
All first-party (ex gson) decoders return well-known empty values defined by Util.emptyValueOf(java.lang.reflect.Type). To customize further, wrap an existing decoder or
make your own.
This flag only works with 404, as opposed to all or arbitrary status codes. This was an
explicit decision: 404 -> empty is safe, common and doesn't complicate redirection, retry or
fallback policy. If your server returns a different status for not-found, correct via a custom
client.
dismiss404 in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>public AsyncFeign.AsyncBuilder<C> errorDecoder(ErrorDecoder errorDecoder)
errorDecoder in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>public AsyncFeign.AsyncBuilder<C> doNotCloseAfterDecode()
BaseBuilderIterator. Feign standard decoders do not
have built in support for this flag. If you are using this flag, you MUST also use a custom
Decoder, and be sure to close all resources appropriately somewhere in the Decoder (you can use
Util.ensureClosed(java.io.Closeable) for convenience).doNotCloseAfterDecode in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>public AsyncFeign.AsyncBuilder<C> decodeVoid()
decodeVoid in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>public AsyncFeign.AsyncBuilder<C> defaultContextSupplier(AsyncContextSupplier<C> supplier)
public <T> T target(Target<T> target)
public AsyncFeign.AsyncBuilder<C> logLevel(Logger.Level logLevel)
logLevel in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>public AsyncFeign.AsyncBuilder<C> contract(Contract contract)
contract in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>public AsyncFeign.AsyncBuilder<C> logger(Logger logger)
logger in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>public AsyncFeign.AsyncBuilder<C> encoder(Encoder encoder)
encoder in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>public AsyncFeign.AsyncBuilder<C> queryMapEncoder(QueryMapEncoder queryMapEncoder)
queryMapEncoder in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>public AsyncFeign.AsyncBuilder<C> options(Request.Options options)
options in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>public AsyncFeign.AsyncBuilder<C> requestInterceptor(RequestInterceptor requestInterceptor)
BaseBuilderrequestInterceptor in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>public AsyncFeign.AsyncBuilder<C> requestInterceptors(Iterable<RequestInterceptor> requestInterceptors)
BaseBuilderrequestInterceptors in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>public AsyncFeign.AsyncBuilder<C> methodInterceptor(MethodInterceptor methodInterceptor)
BaseBuilderMethodInterceptor to the builder. Method interceptors run after contract
resolution and wrap the entire HTTP exchange (request interceptors, HTTP execution, response
interceptors, decoding). They have access to raw method arguments via Invocation.methodInterceptor in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>public AsyncFeign.AsyncBuilder<C> methodInterceptors(Iterable<MethodInterceptor> methodInterceptors)
BaseBuildermethodInterceptors in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>public AsyncFeign.AsyncBuilder<C> invocationHandlerFactory(InvocationHandlerFactory invocationHandlerFactory)
BaseBuilderinvocationHandlerFactory in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>public AsyncFeign<C> internalBuild()
internalBuild in class BaseBuilder<AsyncFeign.AsyncBuilder<C>,AsyncFeign<C>>Copyright © 2012–2026 OpenFeign. All rights reserved.