| Package | Description |
|---|---|
| feign | |
| feign.interceptor |
| Modifier and Type | Field and Description |
|---|---|
protected List<MethodInterceptor> |
BaseBuilder.methodInterceptors |
| Modifier and Type | Method and Description |
|---|---|
List<MethodInterceptor> |
MethodHandlerConfiguration.getMethodInterceptors() |
| Modifier and Type | Method and Description |
|---|---|
Feign.Builder |
Feign.Builder.methodInterceptor(MethodInterceptor methodInterceptor) |
AsyncFeign.AsyncBuilder<C> |
AsyncFeign.AsyncBuilder.methodInterceptor(MethodInterceptor methodInterceptor) |
B |
BaseBuilder.methodInterceptor(MethodInterceptor methodInterceptor)
Adds a single
MethodInterceptor to the builder. |
| Modifier and Type | Method and Description |
|---|---|
Feign.Builder |
Feign.Builder.methodInterceptors(Iterable<MethodInterceptor> methodInterceptors) |
AsyncFeign.AsyncBuilder<C> |
AsyncFeign.AsyncBuilder.methodInterceptors(Iterable<MethodInterceptor> methodInterceptors) |
B |
BaseBuilder.methodInterceptors(Iterable<MethodInterceptor> methodInterceptors)
Sets the full set of method interceptors, overwriting any previously configured.
|
| Constructor and Description |
|---|
MethodHandlerConfiguration(MethodMetadata metadata,
Target<?> target,
Retryer retryer,
List<RequestInterceptor> requestInterceptors,
List<MethodInterceptor> methodInterceptors,
Logger logger,
Logger.Level logLevel,
feign.RequestTemplate.Factory buildTemplateFromArgs,
Request.Options options,
ExceptionPropagationPolicy propagationPolicy) |
| Modifier and Type | Method and Description |
|---|---|
default MethodInterceptor |
MethodInterceptor.andThen(MethodInterceptor next)
Returns a new
MethodInterceptor that invokes the current interceptor first and then the
one passed in. |
| Modifier and Type | Method and Description |
|---|---|
List<MethodInterceptor> |
MethodInterceptors.interceptors() |
| Modifier and Type | Method and Description |
|---|---|
default MethodInterceptor |
MethodInterceptor.andThen(MethodInterceptor next)
Returns a new
MethodInterceptor that invokes the current interceptor first and then the
one passed in. |
| Constructor and Description |
|---|
MethodInterceptors(List<MethodInterceptor> interceptors) |
Copyright © 2012–2026 OpenFeign. All rights reserved.