| Package | Description |
|---|---|
| feign.interceptor |
| Modifier and Type | Field and Description |
|---|---|
static MethodInterceptor.Chain |
MethodInterceptor.Chain.DEFAULT
Sentinel end-of-chain that throws if invoked; the framework provides a real terminal.
|
| Modifier and Type | Method and Description |
|---|---|
default MethodInterceptor.Chain |
MethodInterceptor.apply(MethodInterceptor.Chain chain)
Apply this interceptor to the given chain, producing a chain that runs this interceptor first.
|
| Modifier and Type | Method and Description |
|---|---|
default MethodInterceptor.Chain |
MethodInterceptor.apply(MethodInterceptor.Chain chain)
Apply this interceptor to the given chain, producing a chain that runs this interceptor first.
|
Object |
MethodInterceptor.intercept(Invocation invocation,
MethodInterceptor.Chain chain)
Called for every method invocation on a Feign-built proxy.
|
Copyright © 2012–2026 OpenFeign. All rights reserved.